@@ -176,16 +176,27 @@ def abeles(
         Units = Angstrom**-1
     layers: np.ndarray
         coefficients required for the calculation, has shape (2 + N, 4),
-        where N is the number of layers
-        layers[0, 1] - SLD of fronting (/1e-6 Angstrom**-2)
-        layers[0, 2] - iSLD of fronting (/1e-6 Angstrom**-2)
-        layers[N, 0] - thickness of layer N
-        layers[N, 1] - SLD of layer N (/1e-6 Angstrom**-2)
-        layers[N, 2] - iSLD of layer N (/1e-6 Angstrom**-2)
-        layers[N, 3] - roughness between layer N-1/N
-        layers[-1, 1] - SLD of backing (/1e-6 Angstrom**-2)
-        layers[-1, 2] - iSLD of backing (/1e-6 Angstrom**-2)
-        layers[-1, 3] - roughness between backing and last layer
+        where N is the number of layers:
+
+        - layers[0, 1]
+           SLD of fronting (/1e-6 Angstrom**-2)
+        - layers[0, 2]
+           iSLD of fronting (/1e-6 Angstrom**-2)
+        - layers[N, 0]
+           thickness of layer N
+        - layers[N, 1]
+           SLD of layer N (/1e-6 Angstrom**-2)
+        - layers[N, 2]
+           iSLD of layer N (/1e-6 Angstrom**-2)
+        - layers[N, 3]
+           roughness between layer N-1/N
+        - layers[-1, 1]
+           SLD of backing (/1e-6 Angstrom**-2)
+        - layers[-1, 2]
+           iSLD of backing (/1e-6 Angstrom**-2)
+        - layers[-1, 3]
+           roughness between backing and last layer
+
     scale: float
         Multiply all reflectivities by this value.
     bkg: float
